==> mediawiki_1.11.2.orig.tar.gz: mediawiki-1.11.2/languages/messages/MessagesSn.php <==
<?php
/** Shona (chiShona)
 *
 * @addtogroup Language
 */

$messages = array(
# Dates
'sunday'        => 'Svondo',
'monday'        => 'Muvhuro',
'tuesday'       => 'Chipiri',
'wednesday'     => 'Chitatu',
'thursday'      => 'China',
'friday'        => 'Chishanu',
'saturday'      => 'Mugovera',
'january'       => 'Ndira',
'february'      => 'Kukadzi',
'march'         => 'Kurume',
'april'         => 'Kubvumbi',
'may_long'      => 'Chivabvu',
'june'          => 'Chikumi',
'july'          => 'Chikunguru',
'august'        => 'Nyamavhuvhu',
'september'     => 'Gunyana',
'october'       => 'Gumiguru',
'november'      => 'Mbudzi',
'december'      => 'Zvita',
'january-gen'   => 'Ndira',
'february-gen'  => 'Kukadzi',
'march-gen'     => 'Kurume',
'april-gen'     => 'Kubvumbi',
'may-gen'       => 'Chivabvu',
'june-gen'      => 'Chikumi',
'july-gen'      => 'Chikunguru',
'august-gen'    => 'Nyamavhuvhu',
'september-gen' => 'Gunyana',
'october-gen'   => 'Gumiguru',
'november-gen'  => 'Mbudzi',
'december-gen'  => 'Zvita',

'cancel'         => 'Kanzura',
'qbedit'         => 'Chinja',
'qbspecialpages' => 'Mapeji akakosha',
'mytalk'         => 'Hurukuro dzangu',
'navigation'     => 'Banguranyika',

'help'             => 'Rubatsiro',
'search'           => 'Tsvaga',
'searchbutton'     => 'Tsvaga',
'go'               => 'Enda',
'searcharticle'    => 'Enda',
'history_short'    => 'Zvemakare',
'printableversion' => 'Rinoita kuprinta',
'permalink'        => 'Zvikochekero Zvisingachinje',
'edit'             => 'Chinja',
'delete'           => 'Bharanura',
'protect'          => 'Chengetedza',
'talk'             => 'Hurukuro',
'toolbox'          => 'Maturuzi',
'otherlanguages'   => 'Mimwe Mitauro',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'     => 'Zvirikuitika',
'currentevents-url' => 'Zvirikuitika',
'disclaimers'       => 'Matandanyadzi',
'edithelp'          => 'Mashandurirwo',
'mainpage'          => 'Peji Rekutanga',
'portal'            => 'Mukova wegutse',
'sitesupport'       => 'Zvipo',

'newmessageslink' => 'mashoko matsva',
'editsection'     => 'chinja',
'editold'         => 'chinja',

# Short words for each namespace, by default used in the 'article' tab in monobook
'nstab-main' => 'Gani',

# General errors
'viewsource' => 'Wona mabviro',

# Login and logout pages
'welcomecreation'    => '= Tigashire, $1! == 

Akaunzi yako yagadzirwa. Usakanganwe kuchinga mapreferences ako eWikipedia.',
'yourname'           => 'Zita:',
'yourpassword'       => 'Password:',
'yourpasswordagain'  => 'Nyorazve password:',
'remembermypassword' => 'Ndiyeuke',
'login'              => 'Gamuchirwa',
'userlogin'          => 'Gamuchirwa / Gadzira Akaunzi',
'logout'             => 'Chibuda',
'userlogout'         => 'Chibuda',
'notloggedin'        => 'Hauna kugamuchirwa',
'createaccount'      => 'Gadzira Akaunzi',
'youremail'          => 'E-mail:',
'username'           => 'Zita:',

# Edit pages
'summary'     => 'Muchidimbu',
'minoredit'   => 'Uku kushandurwa kudiki',
'watchthis'   => 'Ringa peji rino',
'savearticle' => 'Kotsa peji',
'showpreview' => 'Ratidza chipandwa',
'showdiff'    => 'Ratidza zvasandurwa',

# Search results
'powersearch' => 'Tsvaga',

# Preferences page
'mypreferences'     => 'Zvandinosarudza',
'prefsnologin'      => 'Hauna kugamuchirwa',
'prefs-rc'          => 'Zvaba Kuchinjwa',
'searchresultshead' => 'Tsvaga',

# Recent changes
'recentchanges' => 'Zvaba Kuchinjwa',

# Recent changes linked
'recentchangeslinked' => 'Zvinoenderana nezvachinjwa',

# Upload
'upload'          => 'Isa fayera',
'uploadbtn'       => 'Isa fayera',
'uploadnologin'   => 'Hauna kugamuchirwa',
'watchthisupload' => 'Ringa peji rino',

# Miscellaneous special pages
'randompage'   => 'Peji nhemwa',
'specialpages' => 'Mapeji akakosha',
'move'         => 'Chichinura',
'movethispage' => 'Chichinura kupeji iri',

# Watchlist
'watchlist'     => 'Zvandakarinda',
'mywatchlist'   => 'Zvandakarinda',
'watch'         => 'Rinda',
'watchthispage' => 'Ringa peji rino',

# Restrictions (nouns)
'restriction-edit' => 'Chinja',
'restriction-move' => 'Chichinura',

# Undelete
'undelete-search-submit' => 'Tsvaga',

# Contributions
'contributions' => 'Mushandisi Kanzatu',
'mycontris'     => 'Kanzatu kangu',

'sp-contributions-submit' => 'Tsvaga',

# What links here
'whatlinkshere' => 'Zvakakochekera pano',

# Move page
'movepage'    => 'Chichinura peji',
'movepagebtn' => 'Chichinura peji',
'movedto'     => 'rachichinurwa ku',
'1movedto2'   => '[[$1]] rachichinurwa ku [[$2]]',
'movereason'  => 'Chikonzero',

# Namespace 8 related
'allmessages' => 'Mashoko esystem',

# Tooltip help for the actions
'tooltip-pt-preferences' => 'Zvandinosarudza',
'tooltip-pt-logout'      => 'Chibuda',
'tooltip-ca-move'        => 'Chichinura kupeji iri',
'tooltip-p-logo'         => 'Peji Rekutanga',

# Trackbacks
'trackbackremove' => ' ([$1 Delete])',

'youhavenewmessagesmulti' => 'Une mashoko matsva pa$1',

# Table pager
'table_pager_limit_submit' => 'Enda',

);

==> mediawiki_1.12.0.orig.tar.gz: mediawiki-1.12.0/languages/messages/MessagesSn.php <==
<?php
/** Shona (chiShona)
 *
 * @addtogroup Language
 *
 * @author Hakka
 */

$messages = array(
# Dates
'sunday'        => 'Svondo',
'monday'        => 'Muvhuro',
'tuesday'       => 'Chipiri',
'wednesday'     => 'Chitatu',
'thursday'      => 'China',
'friday'        => 'Chishanu',
'saturday'      => 'Mugovera',
'january'       => 'Ndira',
'february'      => 'Kukadzi',
'march'         => 'Kurume',
'april'         => 'Kubvumbi',
'may_long'      => 'Chivabvu',
'june'          => 'Chikumi',
'july'          => 'Chikunguru',
'august'        => 'Nyamavhuvhu',
'september'     => 'Gunyana',
'october'       => 'Gumiguru',
'november'      => 'Mbudzi',
'december'      => 'Zvita',
'january-gen'   => 'Ndira',
'february-gen'  => 'Kukadzi',
'march-gen'     => 'Kurume',
'april-gen'     => 'Kubvumbi',
'may-gen'       => 'Chivabvu',
'june-gen'      => 'Chikumi',
'july-gen'      => 'Chikunguru',
'august-gen'    => 'Nyamavhuvhu',
'september-gen' => 'Gunyana',
'october-gen'   => 'Gumiguru',
'november-gen'  => 'Mbudzi',
'december-gen'  => 'Zvita',

'cancel'         => 'Kanzura',
'qbedit'         => 'Chinja',
'qbspecialpages' => 'Mapeji akakosha',
'mytalk'         => 'Hurukuro dzangu',
'navigation'     => 'Banguranyika',

'help'             => 'Rubatsiro',
'search'           => 'Tsvaga',
'searchbutton'     => 'Tsvaga',
'go'               => 'Enda',
'searcharticle'    => 'Enda',
'history_short'    => 'Zvemakare',
'printableversion' => 'Rinoita kuprinta',
'permalink'        => 'Zvikochekero Zvisingachinje',
'edit'             => 'Chinja',
'delete'           => 'Bharanura',
'protect'          => 'Chengetedza',
'talk'             => 'Hurukuro',
'toolbox'          => 'Maturuzi',
'otherlanguages'   => 'Mimwe Mitauro',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'     => 'Zvirikuitika',
'currentevents-url' => 'Project:Zvirikuitika',
'disclaimers'       => 'Matandanyadzi',
'edithelp'          => 'Mashandurirwo',
'mainpage'          => 'Peji Rekutanga',
'portal'            => 'Mukova wegutse',
'sitesupport'       => 'Zvipo',

'newmessageslink'         => 'mashoko matsva',
'youhavenewmessagesmulti' => 'Une mashoko matsva pa$1',
'editsection'             => 'chinja',
'editold'                 => 'chinja',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main' => 'Gani',

# General errors
'viewsource' => 'Wona mabviro',

# Login and logout pages
'welcomecreation'    => '= Tigashire, $1! == 

Akaunzi yako yagadzirwa. Usakanganwe kuchinga mapreferences ako eWikipedia.',
'yourname'           => 'Zita:',
'yourpassword'       => 'Password:',
'yourpasswordagain'  => 'Nyorazve password:',
'remembermypassword' => 'Ndiyeuke',
'login'              => 'Gamuchirwa',
'userlogin'          => 'Gamuchirwa / Gadzira Akaunzi',
'logout'             => 'Chibuda',
'userlogout'         => 'Chibuda',
'notloggedin'        => 'Hauna kugamuchirwa',
'createaccount'      => 'Gadzira Akaunzi',
'youremail'          => 'E-mail:',
'username'           => 'Zita:',

# Edit pages
'summary'     => 'Muchidimbu',
'minoredit'   => 'Uku kushandurwa kudiki',
'watchthis'   => 'Ringa peji rino',
'savearticle' => 'Kotsa peji',
'showpreview' => 'Ratidza chipandwa',
'showdiff'    => 'Ratidza zvasandurwa',

# Search results
'powersearch' => 'Tsvaga',

# Preferences page
'mypreferences'     => 'Zvandinosarudza',
'prefsnologin'      => 'Hauna kugamuchirwa',
'prefs-rc'          => 'Zvaba Kuchinjwa',
'searchresultshead' => 'Tsvaga',

# Recent changes
'recentchanges' => 'Zvaba Kuchinjwa',

# Recent changes linked
'recentchangeslinked' => 'Zvinoenderana nezvachinjwa',

# Upload
'upload'          => 'Isa fayera',
'uploadbtn'       => 'Isa fayera',
'uploadnologin'   => 'Hauna kugamuchirwa',
'watchthisupload' => 'Ringa peji rino',

# Random page
'randompage' => 'Peji nhemwa',

# Miscellaneous special pages
'specialpages' => 'Mapeji akakosha',
'move'         => 'Chichinura',
'movethispage' => 'Chichinura kupeji iri',

# Watchlist
'watchlist'     => 'Zvandakarinda',
'mywatchlist'   => 'Zvandakarinda',
'watch'         => 'Rinda',
'watchthispage' => 'Ringa peji rino',

# Restrictions (nouns)
'restriction-edit' => 'Chinja',
'restriction-move' => 'Chichinura',

# Undelete
'undelete-search-submit' => 'Tsvaga',

# Contributions
'contributions' => 'Mushandisi Kanzatu',
'mycontris'     => 'Kanzatu kangu',

'sp-contributions-submit' => 'Tsvaga',

# What links here
'whatlinkshere' => 'Zvakakochekera pano',

# Move page
'movepage'    => 'Chichinura peji',
'movepagebtn' => 'Chichinura peji',
'movedto'     => 'rachichinurwa ku',
'1movedto2'   => '[[$1]] rachichinurwa ku [[$2]]',
'movereason'  => 'Chikonzero',

# Namespace 8 related
'allmessages' => 'Mashoko esystem',

# Tooltip help for the actions
'tooltip-pt-preferences' => 'Zvandinosarudza',
'tooltip-pt-logout'      => 'Chibuda',
'tooltip-ca-move'        => 'Chichinura kupeji iri',
'tooltip-p-logo'         => 'Peji Rekutanga',

# Trackbacks
'trackbackremove' => ' ([$1 Delete])',

# Table pager
'table_pager_limit_submit' => 'Enda',

);
